API docs for “spamfighter.core.commands.dispatcher”

# Module s.c.c.dispatcher

Part of spamfighter.core.commands View Source

Диспетчеризация команд по имени.

Т.е. отображаем имя команды (атрибут comandName из интерфейса `spamfighter.core.commands.ICommand`) в класс команды.

Function | install | Вариант функции `installCommand` которую можно использовать в определении класса
Function | installCommand | Установить новую команду в карту диспетчеризации.
Function | deinstallCommand | Убрать команду из карты диспетчеризации.
Function | dispatchCommand | Найти класс команды, соответствующий данной команде по имени
Function | listAllCommands | Вернуть список всех команд.

@registrator
def install(command_class): (source)

Вариант функции `installCommand` которую можно использовать в определении класса

Пример использования:

       from spamfighter.core.commands import install, Command
       class MyCommand(Command):
           install()

def installCommand(command_class): (source)
Установить новую команду в карту диспетчеризации.

Parameters | command_class | класс, производный от `Command`

def deinstallCommand(command_class): (source)
Убрать команду из карты диспетчеризации.

Parameters | command_class | класс, производный от `Command`

def dispatchCommand(commandName): (source)
Найти класс команды, соответствующий данной команде по имени

Parameters | commandName | имя команды (type: `str` )
Returns | (type: производная от `Command` )
Raises | errors.CommandUnknownException | если такой команды не существует

def listAllCommands(): (source)
Вернуть список всех команд.